# mlflow-databricks-artifacts
An artifact repository plugin for MLflow that extends ACL'ed artifacts support to older MLflow versions
### Version 2.0
Backport SSE-CPK support to older version Mlflow.

Related PR https://github.com/mlflow/mlflow/pull/6927/files

Doc https://docs.google.com/document/d/1EXrv4-bYoAWl5vRQ1ksRgwqUjheNYgIgeKhfLZQOtRQ/edit#

The mlflow-databricks-artifacts is based on mlflow version v1.29.0